wsipipe.preprocess.patching package
===================================

.. automodule:: wsipipe.preprocess.patching
   :members:
   :undoc-members:
   :show-inheritance:

patch\_finder module
------------------------------------------------

.. automodule:: wsipipe.preprocess.patching.patch_finder
   :members:
   :undoc-members:
   :show-inheritance:

patchset module
-------------------------------------------

.. automodule:: wsipipe.preprocess.patching.patchset
   :members:
   :undoc-members:
   :show-inheritance:

patchset\_utils module
--------------------------------------------------

.. automodule:: wsipipe.preprocess.patching.patchset_utils
   :members:
   :undoc-members:
   :show-inheritance:

